@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Add 32nd, 64th and tuple durations to MIDI-Perl
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0601';
 use strict;
 use warnings;
 
@@ -56,7 +56,7 @@ Music::Duration - Add 32nd, 64th and tuple durations to MIDI-Perl
 
 =head1 VERSION
 
-version 0.0600
+version 0.0601
 
 =head1 SYNOPSIS
 
@@ -76,10 +76,11 @@ version 0.0600
 =head1 DESCRIPTION
 
 This module adds thirty-second and sixty-fourth note divisions to
-L<MIDI::Simple>.  These are 32nd: yn, dyn, ddyn, tyn and 64th: xn, dxn, ddxn, txn.
+L<MIDI::Simple>.  These are 32nd: yn, dyn, ddyn, tyn and 64th: xn, dxn, ddxn,
+txn.
 
 Also, this module allows the addition of non-standard note divisions with the
-B<fractional()> and B<tuple()> functions, detailed below.
+B<tuple()> function.
 
 =head1 FUNCTION
 
@@ -98,7 +99,8 @@ a 3-tuple.
 
 =head1 SEE ALSO
 
-The "Parameters for n/r/noop" section in L<MIDI::Simple>
+The description of the C<Length> hash in the "Parameters for n/r/noop" section
+in L<MIDI::Simple>
 
 The code in the C<t/> directory
 
